CKEDITOR.editorConfig = function(config) {
	config.toolbar_tCMS = [
		['Source'],
		['Cut','Copy','Paste','PasteText','PasteFromWord'],
		['Undo','Redo','-','Find','Replace','-','Link','Unlink','Anchor'],
		['Outdent','Indent','Blockquote','CreateDiv'],
		['JustifyLeft','JustifyCenter','JustifyRight','JustifyBlock'],
		['Bold','Italic','Underline','Strike'],
		['Styles','Format','TextColor','FontSize','-','RemoveFormat']
	];
};
