{% extends "admin/base_site.html" %}

{% block title %}tCMS | {{ _('Site admin') }} | {% block extra_title %}{% endblock %}{% endblock %}

{% block branding %}
<h1 id="site-name">{{ _('CMS administration') }}</h1>
{% endblock %}

{% block breadcrumbs %}
<div class="breadcrumbs">
  <a href="/admin/">Home</a>
  &rsaquo; <a href="/admin/tcms/">{{ _('Cms') }}</a>
  &rsaquo; <a href="/admin/tcms/page/">{{ _('Pages') }}</a>
  {% block extra_breadcrumbs %}{% endblock %}
</div>
{% endblock %}
